# libpythonpro
Módulo para exemplificar construção de projetos Python no curso Pytools

Nesse curso é ensinado como contribuir com projetos de código abertos 

Link para o curso [Python Pro](https://plataforma.dev.pro.br/)

[![Python application](https://github.com/DENILSONdrds/libpythonpro/actions/workflows/python-app.yml/badge.svg)](https://github.com/DENILSONdrds/libpythonpro/actions/workflows/python-app.yml)

Suportada versão 3 de python

Para instalar:

``` console
python3 -m venv .venv
.venv\Scripts\activate
pip install -r requirements-dev.txt
```

Para conferir qualidade de codigo:

```console
flake8
```

Tópicos a serem abordados:
1. Git
2. Virtualenv
3. Pip
